Under x-ipe-docs I need a folder called Knowledge Base which used to maintain knowledges.

I need a sub menu under workplace, called "Knowledge Base"

Knowledge in knowledge base having two sector:
1. Raw Knowledge, it can be any files, codes and folders, and raw knowledge uploaded by default it needs go to landing folder.
2. Processed Knowledge, it's the knowledge being processed, summarized, concluded by AI or some other ways.

Knowledge base
- is using file system and folder structure + indexing technology to organize knowledge
- Knowledge is Multimodal, usually it's text, pdf contain both text and image, ppt, excel with formular
- you can search online which indexing technology is better, such as DAG, knowledge graph, file based search engine, need support at least text and image.

UIUX for knowledge base view
1. I need an knowledge base folder structure view just like the function in ideation.
2. I need top bar actions, one for upload knowledge, it will go to landing folder, uploaded knowledge can be files, the folder contains sub folder or many other files.
3. I need able to search online to claw data.

Need a skill "Knowledge Base Manager" to manage the knowledge in knowledgebase
for example:
1. classify knowledge in landing folder into other folders, if not exist create proper structure which make sense and professional
2. reorg knowlege in it's folder structure and provide adjustment summary
3. generate processed knowledge